from rest_framework import serializers

from accounts.models import User
from web.models import StatusChoices, Article, Comment


class ArticleSerializer(serializers.ModelSerializer):
    class Meta:
        model = Article
        fields = ['id', 'title', 'text', 'author', 'status', 'created_at', 'updated_at']
        read_only_fields = ['author', 'id', 'created_at', 'updated_at']


class ArticlePartialUpdateSerializer(serializers.ModelSerializer):
    title = serializers.CharField(max_length=200, required=False)
    text = serializers.CharField(max_length=3000, required=False)

    class Meta:
        model = Article
        fields = ['id', 'title', 'text', 'author', 'status', 'created_at', 'updated_at']


class AuthorGetSerializer(serializers.ModelSerializer):
    class Meta:
        model = User
        fields = ['username', 'email']


class CommentGetSerializer(serializers.ModelSerializer):
    author = AuthorGetSerializer()

    class Meta:
        model = Comment
        fields = ['text', 'author', 'created_at', 'updated_at']


class ArticleGetSerializer(serializers.ModelSerializer):
    author = AuthorGetSerializer()
    comments = CommentGetSerializer(many=True)

    class Meta:
        model = Article
        fields = [
            'id', 'title',
            'text', 'author',
            'status', 'comments',
            'created_at', 'updated_at',
        ]

#
# class CommentsCreateSerializer(serializers.ModelSerializer):
#     class Meta:
#         model = Comment
#         fields = ['text', 'author']


# class ArticleCreateSerializer(serializers.ModelSerializer):
#     comments = CommentsCreateSerializer(many=True)
#
#     class Meta:
#         model = Article
#         fields = ['title', 'text', 'author', 'status', 'comments']
