from rest_framework.viewsets import ModelViewSet
from rest_framework import permissions

from api import serializers
from web.models import Article


class ArticleViewSet(ModelViewSet):
    queryset = Article.objects.all()
    serializer_class = serializers.ArticleSerializer
    lookup_url_kwarg = 'id'
    method_serializers = {
        'get': serializers.ArticleGetSerializer,
        'patch': serializers.ArticlePartialUpdateSerializer,
    }
    permission_classes = (
        permissions.AllowAny,
        permissions.IsAdminUser,
        permissions.IsAuthenticatedOrReadOnly,
        permissions.DjangoModelPermissions,
        permissions.DjangoModelPermissionsOrAnonReadOnly,
    )

    def get_permissions(self):
        if self.request.method in permissions.SAFE_METHODS:
            return []
        return super().get_permissions()

    def get_serializer_class(self):
        method = self.request.method.lower()
        if method in self.method_serializers:
            return self.method_serializers.get(method)

        return self.serializer_class
